/******************************************************************************
*
* Copyright (C) 2019 Xilinx, Inc. All rights reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
*
*
*
******************************************************************************/
#ifndef _XMICROBLAZE_CONFIG_H_  /* prevent circular inclusions */
#define _XMICROBLAZE_CONFIG_H_  /* by using protection macros */

/***************************** Include Files ********************************/
#include "xmicroblaze.h"

/************************** Variable Definitions ****************************/
extern XMicroblaze_Config XMicroblaze_ConfigTable;

/***************** Macros (Inline Functions) Definitions ********************/
#define XGet_CpuFreq() XMicroblaze_ConfigTable.CpuFreq
#define XGet_CpuId() XMicroblaze_ConfigTable.CpuId
#define XGet_DdrSa() XMicroblaze_ConfigTable.DdrSa
#define XGet_CpuCfgPtr() &XMicroblaze_ConfigTable

#endif // _XMICROBLAZE_CONFIG_H_
